@@ -26,7 +26,7 @@
 #include "com.h"
 #endif /* GRN_COM_H */
 
-#ifdef HAVE_MESSAGE_PACK
+#ifdef WITH_MESSAGE_PACK
 #include <msgpack.h>
 #endif
 
@@ -61,6 +61,7 @@ typedef struct {
   grn_obj values;
   grn_obj level;
   grn_obj columns;
+  uint32_t emit_level;
   int32_t key_offset;
   grn_obj *table;
   grn_obj *last;
@@ -73,10 +74,9 @@ typedef struct {
   grn_content_type input_type;
 } grn_loader;
 
-#define GRN_STACK_SIZE 1024
 #define GRN_CTX_N_SEGMENTS 512
 
-#ifdef ENABLE_MEMORY_DEBUG
+#ifdef USE_MEMORY_DEBUG
 typedef struct _grn_alloc_info grn_alloc_info;
 struct _grn_alloc_info
 {
@@ -105,7 +105,7 @@ struct _grn_ctx_impl {
   grn_strdup_func strdup_func;
 #endif
 
-#ifdef ENABLE_MEMORY_DEBUG
+#ifdef USE_MEMORY_DEBUG
   /* memory debug portion */
   grn_alloc_info *alloc_info;
 #endif
@@ -165,7 +165,7 @@ struct _grn_ctx_impl {
     uint64_t u64;
   } data;
 
-#ifdef HAVE_MESSAGE_PACK
+#ifdef WITH_MESSAGE_PACK
   msgpack_packer msgpacker;
 #endif
 };
