@@ -153,6 +153,10 @@ typedef struct {
    (GRN_TABLE_HASH_KEY <= ((grn_db_obj *)obj)->header.type) &&\
    (((grn_db_obj *)obj)->header.type <= GRN_DB))
 
+typedef grn_rc grn_selector_func(grn_ctx *ctx, grn_obj *table, grn_obj *index,
+                                 int nargs, grn_obj **args,
+                                 grn_obj *res, grn_operator op);
+
 typedef struct _grn_proc_ctx grn_proc_ctx;
 
 struct _grn_proc_ctx {
@@ -177,6 +181,8 @@ struct _grn_proc {
   grn_proc_type type;
   grn_proc_func *funcs[3];
 
+  grn_selector_func *selector;
+
   grn_id module;
   //  uint32_t nargs;
   //  uint32_t nresults;
@@ -196,6 +202,12 @@ GRN_API grn_obj *grn_proc_get_var_by_offset(grn_ctx *ctx, grn_user_data *user_da
 GRN_API grn_obj *grn_proc_alloc(grn_ctx *ctx, grn_user_data *user_data,
                                 grn_id domain, grn_obj_flags flags);
 
+grn_rc grn_proc_set_selector(grn_ctx *ctx, grn_obj *proc,
+                             grn_selector_func selector);
+
+GRN_API grn_rc grn_proc_call(grn_ctx *ctx, grn_obj *proc,
+                             int nargs, grn_obj *caller);
+
 grn_obj *grn_expr_get_or_add_var(grn_ctx *ctx, grn_obj *expr,
                                  const char *name, unsigned int name_size);
 
@@ -236,7 +248,7 @@ enum {
 
 #define DB_OBJ(obj) ((grn_db_obj *)obj)
 
-const char *grn_obj_get_value_(grn_ctx *ctx, grn_obj *obj, grn_id id, uint32_t *size);
+GRN_API const char *grn_obj_get_value_(grn_ctx *ctx, grn_obj *obj, grn_id id, uint32_t *size);
 
 /* vector */
 
@@ -258,6 +270,8 @@ unsigned int grn_vector_pop_element(grn_ctx *ctx, grn_obj *vector,
                                     const char **str, unsigned int *weight, grn_id *domain);
 
 grn_rc grn_vector_delimit(grn_ctx *ctx, grn_obj *v, unsigned int weight, grn_id domain);
+grn_rc grn_vector_decode(grn_ctx *ctx, grn_obj *v, const char *data, uint32_t data_size);
+
 
 grn_rc grn_db_init_builtin_types(grn_ctx *ctx);
 
@@ -408,6 +422,8 @@ grn_id grn_obj_register(grn_ctx *ctx, grn_obj *db, const char *name, unsigned in
 int grn_obj_is_persistent(grn_ctx *ctx, grn_obj *obj);
 void grn_obj_spec_save(grn_ctx *ctx, grn_db_obj *obj);
 
+grn_rc grn_obj_reinit_for(grn_ctx *ctx, grn_obj *obj, grn_obj *domain_obj);
+
 #define GRN_UINT32_POP(obj,value) do {\
   if (GRN_BULK_VSIZE(obj) >= sizeof(uint32_t)) {\
     GRN_BULK_INCR_LEN((obj), -(sizeof(uint32_t)));\
